@@ -23,7 +23,6 @@ from coremltools.converters.mil.mil.ops.registry import SSAOpRegistry
 from coremltools.converters.mil.mil.types.symbolic import (any_symbolic,
                                                            any_variadic,
                                                            is_symbolic)
-from coremltools.libmilstoragepython import _BlobStorageWriter as BlobWriter
 from coremltools.models.neural_network.flexible_shape_utils import (
     NeuralNetworkImageSize, NeuralNetworkImageSizeRange,
     add_enumerated_image_sizes, add_multiarray_ndshape_enumeration,
@@ -37,6 +36,11 @@ from ..backend_helper import (_get_colorspace_enum,
                               _validate_image_input_output_shapes)
 from .passes import mil_passes
 
+try:
+    from coremltools.libmilstoragepython import _BlobStorageWriter as BlobWriter
+except:
+    BlobWriter = None
+
 
 def should_use_weight_file(val):
     return (
@@ -134,9 +138,9 @@ def translate_generic_op(op, parameters, blob_writer, literal_params=[]):
 
         attr_dict["name"] = create_scalar_value(op.name)
         attr_dict["class_name"] = create_scalar_value(class_name)
-        attr_dict["input_order"] = create_list_scalarvalue(input_order, np.str)
-        attr_dict["parameters"] = create_list_scalarvalue(parameters, np.str)
-        attr_dict["weights"] = create_list_scalarvalue(weights, np.str)
+        attr_dict["input_order"] = create_list_scalarvalue(input_order, str)
+        attr_dict["parameters"] = create_list_scalarvalue(parameters, str)
+        attr_dict["weights"] = create_list_scalarvalue(weights, str)
         attr_dict["description"] = create_scalar_value(description)
 
     return pm.Operation(
@@ -271,6 +275,8 @@ def _add_classify_op(prog, classifier_config):
         return out[0].name, out[1].name
 
 def load(prog, weights_dir, resume_on_errors=False, specification_version=_SPECIFICATION_VERSION_IOS_15, **kwargs):
+    if BlobWriter is None:
+        raise RuntimeError("BlobWriter not loaded")
     if "main" not in prog.functions:
         raise ValueError("main function not found in program")
 
