@@ -3,7 +3,9 @@
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
-from coremltools.converters.mil.mil.passes.name_sanitization_utils import NameSanitizer as _NameSanitizer
+from coremltools.converters.mil.mil.passes.name_sanitization_utils import \
+    NameSanitizer as _NameSanitizer
+
 
 class TestNameSanitizer:
 
@@ -19,9 +21,8 @@ class TestNameSanitizer:
                                       ("dense_2_1/BiasAdd", "dense_2_1_BiasAdd"),
                                       ("dense_2_1-BiasAdd", "dense_2_1_BiasAdd"),
                                       ("key:0", "key_0"),
-                                    ]
+        ]
 
         for i, in_and_out_str in enumerate(input_and_expected_strings):
             out = _NameSanitizer().sanitize_name(in_and_out_str[0])
             assert out == in_and_out_str[1]
-
