@@ -3,28 +3,26 @@
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
-from coremltools.converters.mil import testing_reqs
-from coremltools.converters.mil.testing_reqs import *
+import itertools
+
+import numpy as np
+import pytest
+
 from coremltools.converters.mil.frontend.tensorflow.test.testing_utils import (
-    make_tf_graph,
-    run_compare_tf,
-)
-
-# Custom Op imports
-from coremltools.converters.mil.frontend.tensorflow.tf_op_registry import register_tf_op
-
+    TensorFlowBaseTest, make_tf_graph)
 # Importing _TF_OPS_REGISTRY to ensure `overriding` existing TF op does not break
 # testing of default op
 # pytest imports all the tests and hence overriding op invokes custom op which is not expected
 # In real usecase, importing following is not recommended!!
 from coremltools.converters.mil.frontend.tensorflow.tf_op_registry import (
-    _TF_OPS_REGISTRY,
-)
-from coremltools.converters.mil.mil.ops.defs._op_reqs import *
+    _TF_OPS_REGISTRY, register_tf_op)
 from coremltools.converters.mil.mil import Builder as mb
+from coremltools.converters.mil.testing_reqs import backends, compute_units
+from coremltools.converters.mil.testing_utils import random_gen
 
+tf = pytest.importorskip("tensorflow")
 
-class TestCompositeOp:
+class TestCompositeOp(TensorFlowBaseTest):
     @pytest.fixture(scope="class")
     def create_custom_selu(self):
         default_selu = _TF_OPS_REGISTRY.get("Selu", None)
@@ -43,11 +41,15 @@ class TestCompositeOp:
         _TF_OPS_REGISTRY["Selu"] = default_selu
 
     @pytest.mark.parametrize(
-        "use_cpu_only, backend, rank",
-        itertools.product([True, False], backends, list(range(1, 5))),
+        "compute_unit, backend, rank",
+        itertools.product(
+            compute_units,
+            backends,
+            list(range(1, 5))
+        ),
     )
     @pytest.mark.usefixtures("create_custom_selu")
-    def test_selu(self, use_cpu_only, backend, rank):
+    def test_selu(self, compute_unit, backend, rank):
         input_shape = np.random.randint(low=1, high=6, size=rank)
 
         @make_tf_graph([input_shape])
@@ -58,11 +60,10 @@ class TestCompositeOp:
 
         input_values = [random_gen(input_shape, -10.0, 10.0)]
         input_dict = dict(zip(inputs, input_values))
-        run_compare_tf(
+        TensorFlowBaseTest.run_compare_tf(
             model,
             input_dict,
             outputs,
-            use_cpu_only=use_cpu_only,
-            frontend_only=False,
+            compute_unit=compute_unit,
             backend=backend,
         )
