@@ -1621,20 +1621,6 @@ class TestTorchOps:
         expected_result = input_data.masked_fill(mask, value)
         np.testing.assert_allclose(expected_result, ssa.val)
 
-    @pytest.mark.parametrize("sizes", itertools.permutations([1, 2, 3]))
-    def test_meshgrid(self, context, sizes):
-        input_tensors = [torch.rand(size) for size in sizes]
-        expected_results = torch.meshgrid(input_tensors)
-        constants, input_list, output_name = self._gen_constants(3, input_tensors)
-        node = InternalTorchIRNode(
-            kind="meshgrid", inputs=input_list, outputs=[output_name]
-        )
-        ssa = self._construct_test_graph(
-            context, ops.meshgrid, node, output_name, constants=constants,
-        )
-        for expected_result, ssa_result in zip(expected_results, ssa):
-            np.testing.assert_allclose(expected_result.numpy(), ssa_result.val)
-
     @pytest.mark.parametrize(
         "noop_kind",
         ["dropout", "dropout_", "feature_dropout", "contiguous", "device", "detach"],
