@@ -2,15 +2,13 @@
 import numpy as np
 
 from coremltools.converters.mil.mil import types
-from coremltools.converters.mil.mil.input_type import (
-    InputSpec,
-    TensorInputType,
-)
-from coremltools.converters.mil._deployment_compatibility import AvailableTarget as target
+from coremltools.converters.mil.mil.input_type import (InputSpec,
+                                                       TensorInputType)
 from coremltools.converters.mil.mil.operation import Operation
 from coremltools.converters.mil.mil.ops.defs._op_reqs import register_op
 from coremltools.converters.mil.mil.ops.defs.iOS16 import _IOS16_TARGET
 
+
 @register_op(opset_version=_IOS16_TARGET)
 class constexpr_affine_dequantize(Operation):
     """
@@ -51,7 +49,7 @@ class constexpr_affine_dequantize(Operation):
     Returns
     -------
     const tensor<DstT, [1..]>
-  
+
     Attributes
     ----------
     SrcT: uint8, int8
@@ -122,6 +120,8 @@ class constexpr_affine_dequantize(Operation):
     @staticmethod
     def decompress(quantized_data, zero_point, scale, axis):
 
+        axis = axis if axis >= 0 else axis + len(quantized_data.shape)
+
         def rank_promoted_to_same_as_quantized_data(param):
             if len(param.shape) == 0:
                 return np.reshape(param, np.ones(len(quantized_data.shape), np.int32))
@@ -202,7 +202,7 @@ class constexpr_lut_to_dense(Operation):
     * ``NUM_PALETTES`` can be one of ``{2, 4, 16, 64 or 256}``.
     * ``n_bits = log2(NUM_PALETTES)`` can thus be one of ``{1, 2, 4, 6, 8}``.
     * Indices are packed in bytes of size ``M``, where ``M = ceil(n_bits * product(shape) / 8)``.
-    
+
     The bit fields are packed one byte at a time, starting with the least significant bit (LSB) and
     moving upward to the most significant bit (MSB). It follows, naturally, that if an index is split
     across two bytes, the LSBs of that index is filled over the MSBs of current byte, and the remaining
@@ -363,6 +363,10 @@ class constexpr_sparse_to_dense(Operation):
                 "Constraint Violated: M = ceil( product(shape) / 8) where M = mask.size"
             )
 
+        bitarray = np.unpackbits(self.mask.val, bitorder="little")
+        if any(bitarray[i] != 0 for i in range(output_size, len(bitarray))):
+            raise AssertionError("Padded bits in mask should be unset or equals to zero")
+
         dtype = self.nonzero_data.dtype
         shape = self.shape.val
         return types.tensor(dtype, shape)
