@@ -1,21 +1,24 @@
-# -*- coding: utf-8 -*-
-
 #  Copyright (c) 2020, Apple Inc. All rights reserved.
 #
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
-import logging
 from typing import List, Optional
 
 import numpy as np
+
+from coremltools import _logger as logger
+from coremltools.converters.mil.mil import Block
 from coremltools.converters.mil.mil import Builder as mb
-from coremltools.converters.mil.mil import Operation, Block, Var, Program
-from coremltools.converters.mil.mil.passes.pass_registry import register_pass
+from coremltools.converters.mil.mil import Operation, Var
 from coremltools.converters.mil.mil.passes.graph_pass import AbstractGraphPass
+from coremltools.converters.mil.mil.passes.helper import block_context_manager
+from coremltools.converters.mil.mil.passes.pass_registry import register_pass
+
 
 DEBUG = False  # set to true to plot the block before and after the transformation
 
+
 def _check_no_output_connection(block: Block, ops: List[Operation]) -> bool:
     """
     Check that none of the op in this pattern is connected to the output
@@ -237,8 +240,6 @@ def _try_match_and_transform_pattern_1(reduce_op, block) -> bool:
     if root_var.shape is None:
         return False
 
-    rank = len(root_var.shape)
-
     # check that root_var feeds into exactly 3 ops
     if len(list(root_var.child_ops)) != 3:
         return False
@@ -371,8 +372,6 @@ def _try_match_and_transform_pattern_2(reduce_op, block) -> bool:
     if root_var.shape is None:
         return False
 
-    rank = len(root_var.shape)
-
     # check that root_var feeds into exactly 3 ops
     if len(root_var.child_ops) != 3:
         return False
@@ -499,8 +498,6 @@ def _try_match_and_transform_pattern_3(reduce_op, block) -> bool:
     if root_var.shape is None:
         return False
 
-    rank = len(root_var.shape)
-
     # check that root_var feeds into exactly 3 ops
     if len(root_var.child_ops) != 3:
         return False
@@ -651,8 +648,6 @@ def _try_match_and_transform_pattern_4(reduce_op: Operation, block: Block) -> bo
     if root_var.shape is None:
         return False
 
-    rank = len(root_var.shape)
-
     # check that root_var feeds into exactly 4 ops
     if len(root_var.child_ops) != 4:
         return False
@@ -788,7 +783,7 @@ def _try_match_and_transform_pattern_4(reduce_op: Operation, block: Block) -> bo
         reduce_op, block, gamma_var, beta_var, epsilon_var, add_op, ops_to_remove
     )
 
-
+@block_context_manager
 def _fuse_layernorm_or_instancenorm_block(block: Block):
     fusion_status = False
     for i, op in enumerate(list(block.operations)):
@@ -801,20 +796,18 @@ def _fuse_layernorm_or_instancenorm_block(block: Block):
 
         # start pattern match if reduce_mean op is encountered
         if op.op_type == "reduce_mean":
-            with block:
-                if fusion_status is False:
-                    fusion_status = _try_match_and_transform_pattern_1(op, block)
-                if fusion_status is False:
-                    fusion_status = _try_match_and_transform_pattern_2(op, block)
-                if fusion_status is False:
-                    fusion_status = _try_match_and_transform_pattern_3(op, block)
+            if fusion_status is False:
+                fusion_status = _try_match_and_transform_pattern_1(op, block)
+            if fusion_status is False:
+                fusion_status = _try_match_and_transform_pattern_2(op, block)
+            if fusion_status is False:
+                fusion_status = _try_match_and_transform_pattern_3(op, block)
             # has to break as the downstream iterator is affected.
             if fusion_status:
                 return fusion_status
         elif op.op_type == "reduce_sum":
-            with block:
-                if fusion_status is False:
-                    fusion_status = _try_match_and_transform_pattern_4(op, block)
+            if fusion_status is False:
+                fusion_status = _try_match_and_transform_pattern_4(op, block)
             # has to break as the downstream iterator is affected.
             if fusion_status:
                 return fusion_status
@@ -840,7 +833,7 @@ class fuse_layernorm_or_instancenorm(AbstractGraphPass):
                     graphviz.Source(
                         f.get_dot_string(highlight_debug_op_types=["instance_norm"],)
                     ).view(filename="/tmp/block_before_fuse_layernorm_or_instancenorm")
-                logging.debug(
+                logger.debug(
                     "Block before fuse_layernorm_or_instancenorm transform:\n{}".format(f)
                 )
 
@@ -851,6 +844,6 @@ class fuse_layernorm_or_instancenorm(AbstractGraphPass):
                         f.get_dot_string(highlight_debug_op_types=["instance_norm"],)
                     ).view(filename="/tmp/block_after_fuse_layernorm_or_instancenorm")
 
-                logging.debug(
+                logger.debug(
                     "Block after fuse_layernorm_or_instancenorm transform:\n{}".format(f)
                 )
