@@ -1,15 +1,16 @@
-# -*- coding: utf-8 -*-
-
 #  Copyright (c) 2021, Apple Inc. All rights reserved.
 #
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
-from coremltools.converters.mil.mil.passes.pass_registry import register_pass
-from coremltools.converters.mil.mil.passes.graph_pass import AbstractGraphPass
-from coremltools.converters.mil.mil import Builder as mb
 import numpy as np
 
+from coremltools.converters.mil.mil import Builder as mb
+from coremltools.converters.mil.mil.passes.graph_pass import AbstractGraphPass
+from coremltools.converters.mil.mil.passes.helper import block_context_manager
+from coremltools.converters.mil.mil.passes.pass_registry import register_pass
+
+
 def _try_to_transform(linear_op, add_or_sub_op, block):
 
     if add_or_sub_op.x.val is None and add_or_sub_op.y.val is None:
@@ -54,29 +55,31 @@ def _try_to_transform(linear_op, add_or_sub_op, block):
         linear_kargs[k] = v
 
     x = mb.linear(**linear_kargs)
+    
+    if add_or_sub_op.enclosing_block.try_replace_uses_of_var_after_op(
+        anchor_op=add_or_sub_op,
+        old_var=add_or_sub_op.outputs[0],
+        new_var=x,
+    ):
+        add_or_sub_op.enclosing_block.remove_ops([linear_op, add_or_sub_op])
+        return True
+    return False
 
-    add_or_sub_op.enclosing_block.replace_uses_of_var_after_op(
-        anchor_op=add_or_sub_op, old_var=add_or_sub_op.outputs[0], new_var=x
-    )
-    # Remove all the ops at once
-    block.remove_ops([linear_op, add_or_sub_op])
-    return True
-
-
+@block_context_manager
 def _fuse_linear_bias_block(block):
 
-    def _match_pattern(op):
-        if op.op_type == "linear":
-            # abort fusion if op output is also a block output
-            if op.outputs[0] in op.enclosing_block.outputs:
-                return None
-            # find add/sub op
-            child_ops = op.outputs[0].child_ops
-            if len(child_ops) == 1:
-                op_candidate = list(child_ops)[0]
-                if op_candidate.op_type in ["add", "sub"]:
-                    return op_candidate
-        return None
+    def _find_candicate_op(op):
+        if op.op_type != "linear":
+            return None
+        # abort fusion if op output is also a block output
+        if op.outputs[0] in op.enclosing_block.outputs:
+            return None
+        # find add/sub op
+        child_ops = op.outputs[0].child_ops
+        if len(child_ops) == 1:
+            op_candidate = list(child_ops)[0]
+            if op_candidate.op_type in ["add", "sub"]:
+                return op_candidate
 
     fusion_occurred = False
     for op in list(block.operations):
@@ -88,10 +91,9 @@ def _fuse_linear_bias_block(block):
             # This op can't be conv or conv_transpose
             continue
 
-        add_or_sub_op = _match_pattern(op)
+        add_or_sub_op = _find_candicate_op(op)
         if add_or_sub_op is not None:
-            with block:
-                fusion_occurred = _try_to_transform(op, add_or_sub_op, block)
+            fusion_occurred = _try_to_transform(op, add_or_sub_op, block)
             # has to break as the downstream iterator is affected.
             if fusion_occurred:
                 return fusion_occurred
@@ -128,6 +130,7 @@ class fuse_linear_bias(AbstractGraphPass):
 
         prog: Program
     """
+
     def apply(self, prog):
         for f in prog.functions.values():
             block_changed = True
