@@ -1,37 +1,42 @@
-# -*- coding: utf-8 -*-
-
 #  Copyright (c) 2020, Apple Inc. All rights reserved.
 #
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
-
 import numpy as np
-from coremltools.converters.mil.mil.passes.pass_registry import register_pass
-from coremltools.converters.mil.mil.passes.graph_pass import AbstractGraphPass
+
 from coremltools.converters.mil.mil import Builder as mb
+from coremltools.converters.mil.mil.passes.graph_pass import AbstractGraphPass
+from coremltools.converters.mil.mil.passes.helper import block_context_manager
+from coremltools.converters.mil.mil.passes.pass_registry import register_pass
 
 child_op_types = ["add", "sub"]
 
-def _match_pattern(op):
+def _find_candidate_op(op):
 
-    if op.op_type == "matmul":
-        # find add
-        child_ops = op.outputs[0].child_ops
-        if len(child_ops) == 1:
-            add_op_candidate = list(child_ops)[0]
-            if add_op_candidate.op_type in child_op_types:
-                return add_op_candidate
-    return None
+    if op.op_type != "matmul":
+        return None
+    # find add
+    child_ops = op.outputs[0].child_ops
+    if len(child_ops) == 1:
+        add_op_candidate = list(child_ops)[0]
+        if add_op_candidate.op_type in child_op_types:
+            return add_op_candidate
 
-def _transpose(v, before_op):
+def _transpose(v, before_op, name=None):
     """
     Transpose the last 2 dims.
-    v: Var (must be a tensor)
+    v: (Var, must be a tensor)
+    before_op: (Operation) the op right before the new added transpose op
+    name: name for the transpose op if provided
     """
     perm = list(range(v.rank))
     perm[-2], perm[-1] = perm[-1], perm[-2]
-    return mb.transpose(x=v, perm=perm, before_op=before_op)
+
+    if name is None:
+        return mb.transpose(x=v, perm=perm, before_op=before_op)
+    else:
+        return mb.transpose(x=v, perm=perm, before_op=before_op, name=name)
 
 def _try_to_transform(matmul_op, add_op, block):
     if matmul_op.x.val is None and matmul_op.y.val is None:
@@ -50,6 +55,10 @@ def _try_to_transform(matmul_op, add_op, block):
         weight, linear_x = matmul_op.y, matmul_op.x
         transpose_weight = matmul_op.transpose_y.val
         transpose_x = matmul_op.transpose_x.val
+    
+    # We potentially are going to transpose the weight, so if the weight itself is not removable, we skip this path
+    if len(weight.nonreplaceable_vars_upstream) > 0:
+        return False
 
     if linear_x.rank < 2 or weight.rank != 2:
         # We don't support these cases yet.
@@ -109,14 +118,16 @@ def _try_to_transform(matmul_op, add_op, block):
             name=out_name,
         )
 
-    add_op.enclosing_block.replace_uses_of_var_after_op(
-        anchor_op=add_op, old_var=add_op.outputs[0], new_var=x
-    )
-    # Remove all the ops at once
-    block.remove_ops([matmul_op, add_op])
-    return True
-
+    if add_op.enclosing_block.try_replace_uses_of_var_after_op(
+        anchor_op=add_op,
+        old_var=add_op.outputs[0],
+        new_var=x,
+    ):
+        add_op.enclosing_block.remove_ops([matmul_op, add_op])
+        return True
+    return False
 
+@block_context_manager
 def _fuse_matmul_weight_bias_block(block):
     fusion_status = False
     for op in list(block.operations):
@@ -128,10 +139,10 @@ def _fuse_matmul_weight_bias_block(block):
             # This op can't be matmul
             continue
 
-        add_op = _match_pattern(op)
+        add_op = _find_candidate_op(op)
+
         if add_op is not None:
-            with block:
-                fusion_status = _try_to_transform(op, add_op, block)
+            fusion_status = _try_to_transform(op, add_op, block)
             # has to break as the downstream iterator is affected.
             if fusion_status:
                 return fusion_status
@@ -156,6 +167,7 @@ class fuse_matmul_weight_bias(AbstractGraphPass):
 
         prog: Program
     """
+
     def apply(self, prog):
         for f in prog.functions.values():
             block_changed = True
