@@ -3,18 +3,17 @@
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
-import logging
-
-from coremltools.converters.mil.mil.types.symbolic import (
-    is_symbolic,
-    any_variadic,
-    num_symbolic,
-)
+from coremltools import _logger as logger
 from coremltools.converters.mil.mil import Builder as mb
-from coremltools.converters.mil.mil.passes.pass_registry import register_pass
 from coremltools.converters.mil.mil.passes.graph_pass import AbstractGraphPass
+from coremltools.converters.mil.mil.passes.helper import block_context_manager
+from coremltools.converters.mil.mil.passes.pass_registry import register_pass
+from coremltools.converters.mil.mil.types.symbolic import (any_variadic,
+                                                           is_symbolic,
+                                                           num_symbolic)
 
 
+@block_context_manager
 def _remove_symbolic_reshape_block(block):
     num_changes = 0
     for op in list(block.operations):
@@ -44,18 +43,17 @@ def _remove_symbolic_reshape_block(block):
             continue
         # Convert the one symbol to -1
         integer_shape = [-1 if is_symbolic(i) else i for i in shape]
-        with block:
-            shape_const = mb.const(
-                val=integer_shape,
-                name=op.shape.name + "x",
-                before_op=op,
-            )
-            reshaped = mb.reshape(x=op.x, shape=shape_const, name=op.name, before_op=op)
-            op.enclosing_block.replace_uses_of_var_after_op(
-                anchor_op=op, old_var=op.outputs[0], new_var=reshaped
-            )
-            # Remove all the ops at once
-            block.remove_ops([op, op.shape.op])
+        shape_const = mb.const(
+            val=integer_shape,
+            name=op.shape.name + "x",
+            before_op=op,
+        )
+        reshaped = mb.reshape(x=op.x, shape=shape_const, name=op.name, before_op=op)
+        op.enclosing_block.replace_uses_of_var_after_op(
+            anchor_op=op, old_var=op.outputs[0], new_var=reshaped
+        )
+        # Remove all the ops at once
+        block.remove_ops([op, op.shape.op])
         num_changes += 1
     return num_changes
 
@@ -98,4 +96,4 @@ class remove_symbolic_reshape(AbstractGraphPass):
         for f in prog.functions.values():
             num_changes = _remove_symbolic_reshape_block(f)
             msg = "remove_symbolic_reshape: changed {} reshapes."
-            logging.info(msg.format(num_changes))
+            logger.info(msg.format(num_changes))
