@@ -3,16 +3,14 @@
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
-import numpy as np
 import unittest
 
-from coremltools.converters.mil.mil import Builder as mb, types as types
-from coremltools.converters.mil.testing_utils import (
-    assert_model_is_valid,
-    get_op_types_in_program,
-    apply_pass_and_basic_check,
-)
+import numpy as np
 
+from coremltools.converters.mil.mil import Builder as mb
+from coremltools.converters.mil.mil import types as types
+from coremltools.converters.mil.testing_utils import (
+    apply_pass_and_basic_check, assert_model_is_valid, get_op_types_in_program)
 
 np.random.seed(1984)
 
