@@ -2,18 +2,14 @@
 #
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
-
-from coremltools import ImageType, models
-from coremltools.converters.mil.testing_reqs import ct
-from coremltools.converters.mil.testing_utils import (
-    assert_op_count_match,
-    assert_model_is_valid,
-    get_op_types_in_program,
-    apply_pass_and_basic_check,
-)
-from coremltools.converters.mil.mil import Builder as mb
 import unittest
 
+from coremltools import ImageType
+from coremltools.converters.mil.mil import Builder as mb
+from coremltools.converters.mil.testing_utils import (
+    apply_pass_and_basic_check, get_op_types_in_program)
+
+
 class ImagePreprocessingPass(unittest.TestCase):
     """
     Input graph:
@@ -53,6 +49,9 @@ class ImagePreprocessingPass(unittest.TestCase):
         self.assertEqual(get_op_types_in_program(prog), ["transpose", "transpose", "relu", "transpose", "add", "relu"])
 
     def test_fusion_with_image_full(self):
+        # Avoid circular import
+        from coremltools import convert
+
         @mb.program(input_specs=[mb.TensorSpec(shape=(10, 20, 30, 3))])
         def prog(x):
             x1 = mb.transpose(x=x, perm=[0, 3, 1, 2])
@@ -61,9 +60,9 @@ class ImagePreprocessingPass(unittest.TestCase):
             x4 = mb.add(x=x1, y=x3)
             return mb.relu(x=x4)
 
-        mlmodel = ct.convert(prog,
-            inputs=[ImageType(name="x", shape=(10, 20, 30, 3),
-              channel_first=False)],
-            source="mil", convert_to="nn_proto")
+        mlmodel = convert(prog,
+                          inputs=[ImageType(name="x", shape=(10, 20, 30, 3),
+                                            channel_first=False)],
+                          source="milinternal", convert_to="neuralnetwork")
         assert mlmodel is not None
         assert len(mlmodel.get_spec().neuralNetwork.layers) == 3
